==> xl-react-components-0.16.62.tgz: package/app/pages/playground/tabs-playground.js <==
import React, {PureComponent} from 'react';
import PropTypes from 'prop-types';
import R from 'ramda';
import {skins} from '../../xl-react-tab-system/xl-react-tab-system';
import {localeMessages} from '../../services/locale-service';
import DisplayEnumComponent from './display-enum-component';

export default class TabsPlayground extends PureComponent {
    static propTypes = {
        handlers: PropTypes.object,
        skin: PropTypes.string
    };

    render() {
        const {handlers} = this.props;

        return <div className="testBindings">
            <div>
                <span className="label">{localeMessages.apiLabel}</span>
                <button
                    className="xl-react-button xl-primary add-new-tab-btn"
                    onClick={handlers.handleAddTab}
                    type="button">
                    {localeMessages.addNewTabLabel}
                </button>
                <button
                    className="xl-react-button xl-primary toggle-loading-state-btn api-button"
                    onClick={handlers.handleToggleLoading}
                    type="button">
                    {localeMessages.toggleLoadingLabel}
                </button>
            </div>
            <DisplayEnumComponent
                currentValue={this.props.skin}
                label={'Skin'}
                listOfValues={R.values(skins)}
                name={'skin'}
                onInputChange={handlers.handleSkinChange}
            />
        </div>;
    }
}

==> xl-react-components-0.21.15.tgz: package/app/pages/playground/tabs-playground.js <==
import React, {PureComponent} from 'react';
import PropTypes from 'prop-types';
import R from 'ramda';
import {skins} from '../../xl-react-tab-system/xl-react-tab-system';
import {localeMessages} from '../../services/locale-service';
import DisplayEnumComponent from './bindings/display-enum-component';

export default class TabsPlayground extends PureComponent {
    static propTypes = {
        handlers: PropTypes.object,
        skin: PropTypes.string
    };

    render() {
        const {handlers} = this.props;

        return <div className="testBindings">
            <div>
                <span className="label">{localeMessages.apiLabel}</span>
                <button
                    className="xl-react-button xl-primary add-new-tab-btn"
                    onClick={handlers.handleAddTab}
                    type="button">
                    {localeMessages.addNewTabLabel}
                </button>
                <button
                    className="xl-react-button xl-primary toggle-loading-state-btn api-button"
                    onClick={handlers.handleToggleLoading}
                    type="button">
                    {localeMessages.toggleLoadingLabel}
                </button>
            </div>
            <DisplayEnumComponent
                currentValue={this.props.skin}
                label={'Skin'}
                listOfValues={R.values(skins)}
                name={'skin'}
                onInputChange={handlers.handleSkinChange}
            />
        </div>;
    }
}
